# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class CookiesPage(Component):
    """A CookiesPage component.
Lazy loaded CookiesPage

This CookiesPage component tells users about the cookies you’re setting on their device and lets
them accept or reject different types of non-essential cookies.

@param {
id: string,                            // Unique identifier for the cookie component
tag: string                            // Google Analytics tag string
app_insights_conn_string: string       // Application insights connection string
appTitle: string                       // Name of the app
previousPage: string                   // The path to the previous page                   
} [props={}]
@return {*}

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- appTitle (string; optional):
    The name of the app to be referenced in CookiesPage.

- app_insights_conn_string (string; optional):
    Application insights connection string.

- domain (string; optional):
    The domain of the app to be referenced in the cookies, needed for
    deletion of cookies.

- previousPage (string; optional):
    The path to the previous page, which is used in success banner on
    CookiesPage when cookies accepted/rejected.

- tag (string; optional):
    The Google Analytics tag."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'CookiesPage'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        tag: typing.Optional[str] = None,
        app_insights_conn_string: typing.Optional[str] = None,
        appTitle: typing.Optional[str] = None,
        previousPage: typing.Optional[str] = None,
        domain: typing.Optional[str] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'appTitle', 'app_insights_conn_string', 'domain', 'previousPage', 'tag']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'appTitle', 'app_insights_conn_string', 'domain', 'previousPage', 'tag']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(CookiesPage, self).__init__(**args)

setattr(CookiesPage, "__init__", _explicitize_args(CookiesPage.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AutoComplete(Component):
    """An AutoComplete component.
Lazy loaded Autocomplete

@param {
	id,
	autoselect,
	cssNamespace,
	defaultValue,
	displayMenu,
	minLength,
	name,
	placeholder,
	onConfirm,
	confirmOnBlur,
	showNoOptionsFound,
	showAllValues,
	required,
	tNoResults,
	tAssistiveHint,
	source,
	templates,
	dropdownArrow: dropdownArrowFactory,
	tStatusQueryTooShort,
	tStatusNoResults,
	tStatusSelectedOption,
	tStatusResults,
	style,
 errorMessage,
 errorMessageWhenEmpty,
 menu_open, 
} [props={}]
@return {*}

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alwaysDisplayArrow (boolean; optional):
    alwaysDisplayArrow.

- ariaLabelledBy (string; optional):
    This is the ID for the label field.

- autoselect (boolean; optional):
    Should auto select.

- confirmOnBlur (boolean; optional):
    No Description.

- cssNamespace (string; optional):
    cssNamespace.

- displayMenu (string; optional):
    No Description.

- dropdownArrow (boolean | number | string | dict | list; optional):
    React component for dropdown arrow.

- errorMessage (string; optional):
    Error message to display when invalid input entered in dropdown.

- errorMessageWhenEmpty (boolean; optional):
    Whether to display error message when query is empty in dropdown.

- menu_open (boolean; optional):
    Whether the dropdown menu is open. Used to fire a callback   when
    the menu is opened.

- minLength (number; optional):
    No Description.

- name (string; optional):
    No Description.

- placeholder (string; optional):
    No Description.

- required (boolean; optional):
    No Description.

- selectElement (boolean | number | string | dict | list; optional):
    Accessible element.

- showAllValues (boolean; optional):
    No Description.

- showNoOptionsFound (boolean; optional):
    No Description.

- source (boolean | number | string | dict | list; optional):
    No Description.

- tStatusNoResults (boolean | number | string | dict | list; optional):
    No Description.

- tStatusResults (boolean | number | string | dict | list; optional):
    No Description.

- templates (boolean | number | string | dict | list; optional):
    No Description.

- value (string; optional):
    The value displayed in the input.

- wrapperRef (boolean | number | string | dict | list; optional):
    wrapperRef."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'AutoComplete'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        autoselect: typing.Optional[bool] = None,
        cssNamespace: typing.Optional[str] = None,
        displayMenu: typing.Optional[str] = None,
        minLength: typing.Optional[NumberType] = None,
        name: typing.Optional[str] = None,
        placeholder: typing.Optional[str] = None,
        onConfirm: typing.Optional[typing.Any] = None,
        confirmOnBlur: typing.Optional[bool] = None,
        showNoOptionsFound: typing.Optional[bool] = None,
        showAllValues: typing.Optional[bool] = None,
        required: typing.Optional[bool] = None,
        tNoResults: typing.Optional[typing.Any] = None,
        tAssistiveHint: typing.Optional[typing.Any] = None,
        source: typing.Optional[typing.Any] = None,
        templates: typing.Optional[typing.Any] = None,
        tStatusQueryTooShort: typing.Optional[typing.Any] = None,
        tStatusNoResults: typing.Optional[typing.Any] = None,
        tStatusSelectedOption: typing.Optional[typing.Any] = None,
        tStatusResults: typing.Optional[typing.Any] = None,
        dropdownArrow: typing.Optional[typing.Any] = None,
        selectElement: typing.Optional[typing.Any] = None,
        value: typing.Optional[str] = None,
        alwaysDisplayArrow: typing.Optional[bool] = None,
        wrapperRef: typing.Optional[typing.Any] = None,
        style: typing.Optional[typing.Any] = None,
        errorMessage: typing.Optional[str] = None,
        errorMessageWhenEmpty: typing.Optional[bool] = None,
        menu_open: typing.Optional[bool] = None,
        ariaLabelledBy: typing.Optional[str] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'alwaysDisplayArrow', 'ariaLabelledBy', 'autoselect', 'confirmOnBlur', 'cssNamespace', 'displayMenu', 'dropdownArrow', 'errorMessage', 'errorMessageWhenEmpty', 'menu_open', 'minLength', 'name', 'placeholder', 'required', 'selectElement', 'showAllValues', 'showNoOptionsFound', 'source', 'style', 'tStatusNoResults', 'tStatusResults', 'templates', 'value', 'wrapperRef']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'alwaysDisplayArrow', 'ariaLabelledBy', 'autoselect', 'confirmOnBlur', 'cssNamespace', 'displayMenu', 'dropdownArrow', 'errorMessage', 'errorMessageWhenEmpty', 'menu_open', 'minLength', 'name', 'placeholder', 'required', 'selectElement', 'showAllValues', 'showNoOptionsFound', 'source', 'style', 'tStatusNoResults', 'tStatusResults', 'templates', 'value', 'wrapperRef']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AutoComplete, self).__init__(**args)

setattr(AutoComplete, "__init__", _explicitize_args(AutoComplete.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class ChangeLogBanner(Component):
    """A ChangeLogBanner component.


Keyword arguments:

- updates (list of dicts; optional):
    Array of dictionaries representing changelog updates.

    `updates` is a list of dicts with keys:

    - type (string; required)

    - date (string; optional)

    - heading (string; required)

    - link (string; optional)

    - linkTitle (string; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'ChangeLogBanner'
    Updates = TypedDict(
        "Updates",
            {
            "type": str,
            "date": NotRequired[str],
            "heading": str,
            "link": NotRequired[str],
            "linkTitle": NotRequired[str]
        }
    )


    def __init__(
        self,
        updates: typing.Optional[typing.Sequence["Updates"]] = None,
        **kwargs
    ):
        self._prop_names = ['updates']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['updates']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(ChangeLogBanner, self).__init__(**args)

setattr(ChangeLogBanner, "__init__", _explicitize_args(ChangeLogBanner.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class Accordion(Component):
    """An Accordion component.
Lazy loaded Accordion Component

This Accordion component dynamically creates sections based on the provided `accordionHeadings`.
Each section can be independently opened or closed. The `defaultSectionsOpen` array corresponds
to the sections defined by `accordionHeadings`, where each element in the array represents the 
open (true) or closed (false) state of the respective section on initial render.

@param {{
  id: string,                            // Unique identifier for the accordion component
  accordionHeadings: string[],           // Array of headings for each section of the accordion
  children: React.ReactNode,             // Content to be rendered inside the accordion
  showToggleText: boolean,               // Flag to show or hide toggle text  
  defaultSectionsOpen: boolean[],        // Array indicating the initial open state of each section
}} [props={}]                            // Component props with default empty object
@return {React.ReactElement}             // Returns a React element representing the accordion

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    Array of accordion children.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- accordionHeadings (list of strings; optional):
    Array of accordion headings.

- bannerSections (list of number | a value equal to: nulls; optional):
    Array that determines the creation of banners for each section.
    Each item in the array corresponds to a section on the page. If an
    item is an integer, a banner with a button is created.  The button
    focuses on the child content with the corresponding index. If an
    item is None, no banner is created for that section.

- defaultSectionsOpen (list of booleans; optional):
    Array of booleans that determines the initial open/closed state of
    each section in the component. Each item in the array corresponds
    to a section. If an item is True, the corresponding section is
    open  by default when the component is first rendered. If an item
    is False, the corresponding section is closed by default.

- showToggleText (boolean; default True):
    Whether to display \"Show\" / \"Hide\" text before Accordion
    heading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'Accordion'


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        accordionHeadings: typing.Optional[typing.Sequence[str]] = None,
        bannerSections: typing.Optional[typing.Sequence[typing.Union[NumberType, Literal[None]]]] = None,
        showToggleText: typing.Optional[bool] = None,
        defaultSectionsOpen: typing.Optional[typing.Sequence[bool]] = None,
        **kwargs
    ):
        self._prop_names = ['children', 'id', 'accordionHeadings', 'bannerSections', 'defaultSectionsOpen', 'showToggleText']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'accordionHeadings', 'bannerSections', 'defaultSectionsOpen', 'showToggleText']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Accordion, self).__init__(children=children, **args)

setattr(Accordion, "__init__", _explicitize_args(Accordion.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class ComboBox(Component):
    """A ComboBox component.


Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- allowsCustomValue (boolean; optional)

- defaultInputValue (string; optional)

- defaultItems (boolean | number | string | dict | list; optional)

- items (list | list; optional)

- label (string; optional)

- menuTrigger (string; optional)

- selectedKey (string | number; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'ComboBox'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        label: typing.Optional[str] = None,
        defaultInputValue: typing.Optional[str] = None,
        defaultItems: typing.Optional[typing.Any] = None,
        items: typing.Optional[typing.Union[typing.Sequence[typing.Any]]] = None,
        onSelectionChange: typing.Optional[typing.Any] = None,
        allowsCustomValue: typing.Optional[bool] = None,
        onInputChange: typing.Optional[typing.Any] = None,
        selectedKey: typing.Optional[typing.Union[str, NumberType]] = None,
        menuTrigger: typing.Optional[str] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'allowsCustomValue', 'defaultInputValue', 'defaultItems', 'items', 'label', 'menuTrigger', 'selectedKey']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowsCustomValue', 'defaultInputValue', 'defaultItems', 'items', 'label', 'menuTrigger', 'selectedKey']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(ComboBox, self).__init__(**args)

setattr(ComboBox, "__init__", _explicitize_args(ComboBox.__init__))
